gap> x := Indeterminate( Rationals, "x" );;
gap> f := UnivariatePolynomial( Rationals, [1,3,4,1] );
x^3+4*x^2+3*x+1
gap> L := SplittingField( f );
<algebraic extension over the Rationals of degree 6>
gap> y := Indeterminate( L, "y" );;
gap> FactorsPolynomialAlgExt( L, f );
[ y+(-3/94*a^4-24/47*a^3-253/94*a^2-535/94*a-168/47),
  y+(-3/94*a^4-24/47*a^3-253/94*a^2-441/94*a+20/47),
  y+(3/47*a^4+48/47*a^3+253/47*a^2+488/47*a+336/47) ]
gap> IsomorphicMatrixField( L );
<rational matrix field of degree 6>
gap> Display(RootsAsMatrices(f)[1]);
[ [   0,   1,   0,   0,   0,   0 ],
  [   0,   0,   1,   0,   0,   0 ],
  [  -1,  -3,  -4,   0,   0,   0 ],
  [   0,   0,   0,   0,   1,   0 ],
  [   0,   0,   0,   0,   0,   1 ],
  [   0,   0,   0,  -1,  -3,  -4 ] ]
gap> MinimalPolynomial( Rationals, RootsAsMatrices(f)[1]);
x^3+4*x^2+3*x+1
gap> iso := IsomorphismMatrixField( L );
MappingByFunction( <algebraic extension over the Rationals of degree
6>, <rational matrix field of degree
6>, function( x ) ... end, function( mat ) ... end )
gap> PreImages( iso, RootsAsMatrices( f ) );
[ -3/47*a^4-48/47*a^3-253/47*a^2-488/47*a-336/47,
  3/94*a^4+24/47*a^3+253/94*a^2+441/94*a-20/47,
  3/94*a^4+24/47*a^3+253/94*a^2+535/94*a+168/47 ]
gap> GaloisGroupOnRoots(f);
Group([ (2,3), (1,2) ])
"dvi"
"latex"
"maple"
"off"
\endexample

\> RootsOfPolynomialAsRadicalsNC( <f> [, <mode> [, <file> ] ] )

does essentially the same as `RootsOfPolynomialAsRadicals' except
that it runs no test on the input before starting the actual
computation. Therefore it can be used for polynomials with arbitrary
degree, but it may run for a very long time until a
non-solvable polynomial is recognized as such.

Detailed examples for these two functions can be found in the next section.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\Section{Examples}

The function `RootsOfPolynomialAsRadicals' does not generate output
inside \GAP. Depending on the chosen mode, various kinds
of files can be created. As an example the polynomial from the
introduction will be considered.

\beginexample
gap> g := UnivariatePolynomial( Rationals, [1,1,-1,-1,1] );
x^4-x^3-x^2+x+1
gap> RootsOfPolynomialAsRadicals(g);
"/tmp/tmp.8zkw5B/Nst.tex"
gap> RootsOfPolynomialAsRadicals(g, "maple");
"/tmp/tmp.k9aTCz/Nst"
w1 := (-3)^(1/2);
w2 := ((7/2) + (-1/2)*w1)^(1/2);
w3 := ((7/2) + (1/2)*w1)^(1/2);

a := (1/4) + (1/4)*w1 + (1/2)*w3;
gap> RootsOfPolynomialAsRadicalsNC( g, "off" );
gap> time;
0
gap> SplittingField( g );
<algebraic extension over the Rationals of degree 8>
gap> time;
0
gap> GaloisGroupOnRoots( g );
Group([ (2,4), (1,2)(3,4) ])
gap> time;
0
